pub async fn notify_text(cmd: &Notify, run: &str, summary: &str) -> Result<()>
notify for an event that is not a question: the same command, the same placeholders, with summary and run supplied directly.
notify
summary
run