sanitize_patch

Function sanitize_patch 

pub fn sanitize_patch(
    site: &str,
    patch: &str,
    cfg: &Blind,
) -> (String, Vec<Leak>)
Apply the configured leak policy to a patch body.

Returns the text to show the judges plus everything found.