pub enum MergeMode {
None,
Local,
Pr,
}Expand description
What to do with the winning branch.
Variants
None
Leave the branch alone and print the merge command matching
Merge::style.
Local
Merge into the base branch in the primary worktree, using
Merge::style.
Pr
Push the branch and open a PR with gh pr create. Landing this PR
([graph] land) always squashes — see land’s module doc — so
Merge::style does not apply here.