pub enum Screened {
Clean,
Cleared(Judgement),
Unjudged(String),
}Expand description
How screen let work through.
Variants
Clean
No identifier matched; no judge was asked.
Cleared(Judgement)
A match was found and the judge said it is not a duplicate.
Unjudged(String)
A match was found and nobody could judge it (the reason): let through.