pub async fn rebase_abort(repo: &Path, scratch: &Path)Expand description
Abandon a rebase left standing by rebase_start and drop its worktree.
The branch is exactly where it was before the rebase began.
pub async fn rebase_abort(repo: &Path, scratch: &Path)Abandon a rebase left standing by rebase_start and drop its worktree.
The branch is exactly where it was before the rebase began.