release_worktree_config

Function release_worktree_config 

pub async fn release_worktree_config(repo: &Path) -> Result<()>
Release a reference taken by acquire_worktree_config.

Only the last release for a repository actually calls disable_worktree_config, and only when this process was the one that turned the setting on in the first place.