worktree_holding

Function worktree_holding 

pub async fn worktree_holding(
    repo: &Path,
    branch: &str,
) -> Result<Option<PathBuf>>
Where branch is checked out, if some worktree holds it.

Read from git worktree list --porcelain rather than out of an error message, which varies with git’s version and locale.