pub struct Released {
pub old_id: String,
/* private fields */
}Expand description
A worktree that was released, with what is needed to put it back if the review that took the branch over never starts.
Fields
old_id: StringThe run whose worktree was released.
Implementations