scan

Function scan 

pub fn scan(text: &str) -> Vec<Token>
Pull magi/<run>/<label> branch names and 7-40 digit hex shas out of text, branch names first, then in order of first appearance, without duplicates. A sha must contain a digit, which drops words such as defaced and facade.