pub struct LandApproval {
pub question: String,
pub head: String,
}Expand description
A merge-approval question and the head commit it was asked about.
Fields
question: StringId of the question that was filed for head.
head: StringThe commit the question’s panel was built from.