tasks_of

Function tasks_of 

pub fn tasks_of(queue: &Queue, talk_id: &str) -> Vec<Task>
Queue tasks this conversation has filed, oldest first.

A task is this conversation’s when its Source::Agent names this conversation’s id as run - which is exactly what happens when magi task add is run from inside a turn, because [turn] passes the conversation’s own id as Invocation::run.