read_note

Function read_note 

pub fn read_note(home: &Path, progress: &Progress) -> Option<String>
The watchdog’s message for exactly this stage of this upgrade, if any; a note from another stage or another upgrade is ignored.