pub fn answer_for_agent(q: &Question, answer: &str) -> String
What the agent is shown for an answer: the owner’s says it has not read yet, in order, then the answer. With no such say it is answer itself, byte for byte.
answer