pub fn remote_head_branch(remote: &str, symref: &str) -> Option<String>Expand description
The branch a refs/remotes/<remote>/HEAD symref names, e.g.
refs/remotes/origin/main -> main. Pure, and shared with
Config::discover so the branch magi reads its config from and the branch
a run starts from can never come from two different readings.